open

package module
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 4, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrNotSupported = errors.New("not supported")

ErrNotSupported occurs when no ways to open a file are found.

Functions

func Open

func Open(ctx context.Context, input string) error

Open the given input.

func With

func With(ctx context.Context, app, input string) error

With opens the given input using the given app.

Types

This section is empty.

Directories

Path Synopsis

Jump to